@@ -17,6 +17,15 @@ source "/debcraft-repository.sh"
 
 apt-get update
 
+# Normally dpkg-source applies the patches, but when running a binary-only
+# build directly in the Debian packaging git repository dpkg-source will be
+# skipped and sources will remain unpatched
+if [ -f debian/patches/series ]
+then
+  log_warn "Debian patches are *not* applied automatically as sources are tested as-is."
+  log_warn "Run 'gbp pq import --force' or equivalent to apply patches before starting tests."
+fi
+
 log_info "Run autopkgtest"
 autopkgtest --ignore-restrictions=breaks-testbed --no-built-binaries --shell-fail -- null
 
