@@ -12,10 +12,10 @@ function get_baseimage_from_distribution_name() {
     unstable)
       echo "debian:sid"
       ;;
-    experimental | sid | trixie | bookworm | bullseye | buster)
+    experimental | sid | trixie | bookworm | bullseye | buster | stretch )
       echo "debian:$NAME"
       ;;
-    oracular | noble | mantic | jammy | focal)
+    plucky | oracular | noble | mantic | jammy | focal)
       echo "ubuntu:$NAME"
       ;;
     *)
@@ -39,7 +39,7 @@ function get_ubuntu_equivalent_from_debian_release() {
   then
     # NOTE! This line needs to be updated 2x year
     # @TODO: Ideally read last line from /usr/share/distro-info/ubuntu.csv directly
-    echo "oracular"
+    echo "plucky"
   else
     # Historical equivalents for each Ubuntu release based on what Debian
     # release happened around the same time and thus have most of the package
@@ -47,7 +47,7 @@ function get_ubuntu_equivalent_from_debian_release() {
     #
     # @TODO: Ideally read /usr/share/distro-info/ubuntu.csv directly
     case $SERIES in
-      oracular | noble | mantic | lunar | jammy | hirsute | focal | disco | bionic | zesty)
+      plucky | oracular | noble | mantic | lunar | jammy | hirsute | focal | disco | bionic | zesty)
         # For every Ubuntu name always return it as-is
         echo "$SERIES"
         ;;
